summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-08-03 19:56:15 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-08-05 14:51:49 -0500
commitff3171322c4f4ba20e47c34e60d105596d17ecc1 (patch)
treedcb0b4eb3dca6e579c3363539462e2f5079536ce
parent1ee1fcc8052415445a178f765012750d97484910 (diff)
downloadlibpng-ff3171322c4f4ba20e47c34e60d105596d17ecc1.tar.gz
[libpng15] Imported from libpng-1.5.19beta04.tarv1.5.19beta04
-rw-r--r--CMakeLists.txt6
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--pngpread.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rwxr-xr-x[-rw-r--r--]scripts/dfn.awk0
-rw-r--r--scripts/makefile.amiga2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
16 files changed, 32 insertions, 30 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index cb4982abe..dffc31b4a 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -1,6 +1,6 @@
# CMakeLists.txt
-# Copyright (C) 2007-2013 Glenn Randers-Pehrson
+# Copyright (C) 2007-2014 Glenn Randers-Pehrson
# This code is released under the libpng license.
# For conditions of distribution and use, see the disclaimer
@@ -185,6 +185,8 @@ macro(CREATE_SYMLINK SRC_FILE DEST_FILE)
ADD_CUSTOM_TARGET(${DEST_FILE}_COPY ALL DEPENDS ${CMAKE_LIBRARY_OUTPUT_DIRECTORY}/${DEST_FILE})
else(WIN32 AND NOT CYGWIN AND NOT MSYS)
get_filename_component(LINK_TARGET "${SRC_FILE}" NAME)
+ execute_process(COMMAND ${CMAKE_COMMAND} -E make_directory ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_LIBRARY_OUTPUT_DIRECTORY})
+ execute_process(COMMAND ${CMAKE_COMMAND} -E create_symlink "${LINK_TARGET}" ${CMAKE_LIBRARY_OUTPUT_DIRECTORY}/${DEST_FILE} WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR})
execute_process(COMMAND ${CMAKE_COMMAND} -E create_symlink "${LINK_TARGET}" ${CMAKE_LIBRARY_OUTPUT_DIRECTORY}/${DEST_FILE} WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR})
execute_process(COMMAND ${CMAKE_COMMAND} -E create_symlink "${LINK_TARGET}" ${DEST_FILE} WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR})
endif(WIN32 AND NOT CYGWIN AND NOT MSYS)
@@ -315,7 +317,7 @@ if(PNG_EXPORT_RULE AND NOT SKIP_INSTALL_EXPORT AND NOT SKIP_INSTALL_ALL )
install(EXPORT libpng DESTINATION lib/libpng FILE lib${PNG_LIB_NAME}.cmake)
endif()
-# what's with libpng-$VER%.txt and all the extra files?
+# what's with libpng-manual.txt and all the extra files?
# UNINSTALL
# do we need this?
diff --git a/LICENSE b/LICENSE
index fb3d0c4f5..f6a3c1dc4 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.19beta04, April 6, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.19beta04, August 4, 2014, are
Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-April 6, 2014
+August 4, 2014
diff --git a/README b/README
index 5f553a8bf..82330ae05 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.19beta04 - April 6, 2014 (shared library 15.0)
+README for libpng version 1.5.19beta04 - August 4, 2014 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index bf22694d6..f7e87fc7a 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.19beta04 - April 6, 2014
+ libpng version 1.5.19beta04 - August 4, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.19beta04 - April 6, 2014
+ libpng versions 0.97, January 1998, through 1.5.19beta04 - August 4, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -4531,7 +4531,7 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-April 6, 2014
+August 4, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index 655fce2e9..06fd2ba34 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "April 6, 2014"
+.TH LIBPNG 3 "August 4, 2014"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.19beta04
.SH SYNOPSIS
@@ -492,7 +492,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.19beta04 - April 6, 2014
+ libpng version 1.5.19beta04 - August 4, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -503,7 +503,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.19beta04 - April 6, 2014
+ libpng versions 0.97, January 1998, through 1.5.19beta04 - August 4, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -5023,7 +5023,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-April 6, 2014
+August 4, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -5321,7 +5321,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.19beta04 - April 6, 2014:
+Libpng version 1.5.19beta04 - August 4, 2014:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5344,7 +5344,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.19beta04, April 6, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.19beta04, August 4, 2014, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5443,7 +5443,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-April 6, 2014
+August 4, 2014
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 423c28d13..c1279cdbc 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "April 6, 2014"
+.TH LIBPNGPF 3 "August 4, 2014"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.19beta04
(private functions)
diff --git a/png.5 b/png.5
index 3ab560e2a..ae15f36ae 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "April 6, 2014"
+.TH PNG 5 "August 4, 2014"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index d885c1217..b84c3ee7a 100644
--- a/png.c
+++ b/png.c
@@ -658,13 +658,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.19beta04 - April 6, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.5.19beta04 - August 4, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.19beta04 - April 6, 2014\
+ return "libpng version 1.5.19beta04 - August 4, 2014\
Copyright (c) 1998-2014 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 0ed7924b1..003087264 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.19beta04 - April 6, 2014
+ * libpng version 1.5.19beta04 - August 4, 2014
*
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpread.c b/pngpread.c
index e0842c7fd..710fec0e7 100644
--- a/pngpread.c
+++ b/pngpread.c
@@ -1291,7 +1291,7 @@ png_progressive_combine_row (png_structp png_ptr, png_bytep old_row,
* it must be png_ptr->row_buf+1
*/
if (new_row != NULL)
- png_combine_row(png_ptr, old_row, 1/*display*/);
+ png_combine_row(png_ptr, old_row, 1/*blocky display*/);
}
#endif /* PNG_READ_INTERLACING_SUPPORTED */
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 8c694ff9f..d29700c67 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.19beta04 - April 6, 2014
+libpng version 1.5.19beta04 - August 4, 2014
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index c4eba0d98..7f0253dde 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.19beta04 - April 6, 2014
+ * libpng version 1.5.19beta04 - August 4, 2014
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/dfn.awk b/scripts/dfn.awk
index 54a8ea3ca..54a8ea3ca 100644..100755
--- a/scripts/dfn.awk
+++ b/scripts/dfn.awk
diff --git a/scripts/makefile.amiga b/scripts/makefile.amiga
index ba10650e8..16a4bd5d3 100644
--- a/scripts/makefile.amiga
+++ b/scripts/makefile.amiga
@@ -46,7 +46,7 @@ $(AR) libpng.lib r $(OBJS)
$(OBJS): pngpriv.h png.h pngconf.h pnglibconf.h pnginfo.h pngstruct.h pngdebug.h
pnglibconf.h: $(PNGLIBCONF_H_PREBUILT)
-COPY scripts/pnglibconf.h.prebuilt TO pnglibconf.h
+COPY $(PNGLIBCONF_H_PREBUILT) TO pnglibconf.h
pngtest: pngtest.o libpng.lib
$(LN) <WITH <
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 18717aa6f..f446387ea 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,7 +1,7 @@
/* 1.5.19beta04 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* libpng version 1.5.19beta04 - April 6, 2014 */
+/* libpng version 1.5.19beta04 - August 4, 2014 */
/* Copyright (c) 1998-2013 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index b5c0682f4..98d6256c7 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.19beta04 - April 6, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.19beta04 - April 6, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -228,7 +228,7 @@
*
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.19beta04, April 6, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.19beta04, August 4, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -340,7 +340,7 @@
* Y2K compliance in libpng:
* =========================
*
- * April 6, 2014
+ * August 4, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -409,7 +409,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.5.19beta04"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.19beta04 - April 6, 2014\n"
+ " libpng version 1.5.19beta04 - August 4, 2014\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.19beta04 - April 6, 2014
+ * libpng version 1.5.19beta04 - August 4, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.19beta04 - April 6, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.19beta04 - August 4, 2014: Glenn
* See also "Contributing Authors", below.
*